Coverage report

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
sphinxlint/__init__.py | 4 | 0 | 0 | 100%
sphinxlint/__main__.py | 2 | 2 | 2 | 0%
sphinxlint/__main___BASE_7374.py | 121 | 121 | 2 | 0%
sphinxlint/__main___LOCAL_7374.py | 2 | 2 | 2 | 0%
sphinxlint/__main___REMOTE_7374.py | 121 | 121 | 2 | 0%
sphinxlint/checkers.py | 252 | 28 | 0 | 89%
sphinxlint/cli.py | 131 | 30 | 0 | 77%
sphinxlint/rst.py | 53 | 0 | 0 | 100%
sphinxlint/sphinxlint.py | 52 | 8 | 0 | 85%
sphinxlint/utils.py | 131 | 6 | 0 | 95%
tests/test_default_role_re.py | 10 | 0 | 0 | 100%
tests/test_enable_disable.py | 41 | 0 | 0 | 100%
tests/test_filter_out_literal.py | 74 | 0 | 0 | 100%
tests/test_po2rst.py | 9 | 0 | 0 | 100%
tests/test_sphinxlint.py | 62 | 0 | 0 | 100%
tests/test_xpass_friends.py | 13 | 0 | 0 | 100%
Total | 1078 | 318 | 8 | 71%

No items found using the specified filter.